function load_image

clear
clear global

global faces num numrow numcol vecsize meanface newfaces V D eigfaces errors
global meanall n dirnum Sb Sw Wfld Wopt Sw2 Sb2 I imagestr meanstr fishstr
global rimage projmean projimage Wqr projmean_qr projimage_qr rimage_qr 
global errors_qr qrstr Wsvd1 projmean_svd1 projimage_svd1 rimage_svd1
global Wsvd2 projmean_svd2 projimage_svd2 rimage_svd2 errors_svd1 errors_svd2
global Wmean projmean_mean projimage_mean rimage_mean errors_mean
global meanfacestr svd1str svd2str

% get the directory from the user
dirstr = inputdlg('Please enter the directory containing the images');
[rows, cols] = size(dirstr);
if rows == 0 & cols == 0
    return;
end

dirs = dir(char(dirstr));
[dirrows, dircols] = size(dirs);

% form the image matrice
h = waitbar(0, 'Please wait while loading the images ...');
dirnum = 0;
n = 0;
for i = 1:dirrows
    if strcmp(dirs(i).name, '.') == 0 & strcmp(dirs(i).name, '..') == 0
	files = dir([char(dirstr), '/', dirs(i).name]);
	[rows, cols] = size(files);

	num(dirnum+1) = 0;
	for j = 1:rows
	    if strcmp(files(j).name,'.')==0 & strcmp(files(j).name,'..')==0
	        [r,c] = size(files(j).name);
	        ext = files(j).name(c-3:c);
	        if strcmp(files(j).name(c-3), '.') == 1 & (strcmp(ext, 'jpg') == 0 | strcmp(ext, 'bmp') == 0 | strcmp(ext, 'tif') == 0 | strcmp(ext, 'png') == 0 | strcmp(ext, 'hdf') == 0 | strcmp(ext, 'pcx') == 0 | strcmp(ext, 'xwd') == 0)

	            face = imread([char(dirstr), '/', dirs(i).name, '/', files(j).name]);
		    if num(dirnum+1) == 0
			if dirnum == 0
			    [numrow, numcol] = size(face);
	                    vecsize = numrow*numcol;
			    meanall = zeros(vecsize, 1);
		        end
	                meanface(:,dirnum+1) = zeros(vecsize, 1);
		    end
		    faces(:,n+1) = reshape(transpose(double(face)), vecsize,1);
		    faces(:,n+1) = faces(:,n+1) - min(faces(:,n+1));
		    faces(:,n+1) = round(faces(:,n+1)*255/max(faces(:,n+1)));
		    meanface(:,dirnum+1) = meanface(:,dirnum+1) + faces(:,n+1);
		    meanall = meanall + faces(:,n+1);
		    num(dirnum+1) = num(dirnum+1) + 1;
		    n = n + 1;
	        end
	    end
	end
	dirnum = dirnum + 1;
    end
    waitbar(i/dirrows, h);
end
close(h);


% find the mean face image
% subtract the mean from the image matrice
h = waitbar(0, 'Subtracting the mean from all the images ...');
meanall = meanall / n;
for i = 1:n
    newfaces(:,i) = faces(:,i) - meanall;
    waitbar(i/n, h);
end
close(h);


% find the mean of each class
h = waitbar(0, 'Finding the mean of each image class ...');
for i = 1:dirnum
    meanface(:,i) = meanface(:,i) / num(i);
    waitbar(i/dirnum, h);
end
close(h);


% form covariance matrice
h = waitbar(0.05, 'Finding the Wpca ...');
[V,D] = eig(transpose(newfaces) * newfaces);
waitbar(0.1, h);
V = newfaces * V;
waitbar(0.15, h);
[Y, I] = sort(diag(D));
I = flipud(I);
waitbar(0.2, h);
for i = 1:n-dirnum
    eigfaces(:,i) = V(:,I(i));
    eigfaces(:,i) = eigfaces(:,i) / norm(eigfaces(:,i));
    waitbar(0.2 + i * 0.8 / (n-dirnum), h);
end
close(h);


% Find Sb
h = waitbar(0, 'Finding the between-class scatter matrix ...');
for i = 1:dirnum
    Sb(:,i) = sqrt(num(i)) * (meanface(:,i) - meanall);
    waitbar(i/dirnum, h);
end
Sb2 = transpose(eigfaces) * Sb * transpose(Sb) * eigfaces;
close(h);


% Find Sw
h = waitbar(0, 'Finding the within-class scatter matrix ...');
j = 1;
k = 1;
for i = 1:n
    Sw(:,i) = faces(:,i) - meanface(:,j);
    k = k + 1;
    if k > num(j)
	j = j + 1;
	k = 1;
    end
    waitbar(i/n, h);
end
Sw2 = transpose(eigfaces) * Sw * transpose(Sw) * eigfaces;
close(h);


% Find the Wfld
h = waitbar(0.10, 'Finding the Wfld ...');
[V,D] = eig(inv(Sw2) * Sb2);
waitbar(0.15, h);
[Y, I] = sort(diag(D));
I = flipud(I);
waitbar(0.2, h);
for i = 1:dirnum-1
    Wfld(:,i) = V(:,I(i));
    waitbar(0.2 + i * 0.8 / (dirnum-1), h);
end
close(h);


% Form Wopt, projected meanface and images for FF
h=waitbar(0,'Finding Wopt, projected meanfaces and images for FisherFace ...');
Wopt = eigfaces * Wfld;
waitbar(0.4, h);
projmean = Wopt' * meanface;
waitbar(0.7, h);
projimage = Wopt' * faces;
waitbar(1, h);
close(h);

% Form Wqr, projected meanface and images for QR
h=waitbar(0,'Finding Wqr, projected meanfaces and images for QR ...');
[Wqr, R] = qr(meanface, 0);
waitbar(0.4, h);
projmean_qr = Wqr' * meanface;
waitbar(0.7, h);
projimage_qr = Wqr' * faces;
waitbar(1, h);
close(h);

% Form Wmean, projected meanface and images for MEANFACE
h=waitbar(0,'Finding Wmean, projected meanfaces and images for MEANFACE ...');
for i = 1:dirnum
    temp2(:,i) = meanface(:,i) - meanall;
    waitbar(0.4*i/dirnum, h);
end
Wmean = orth(temp2);
waitbar(0.6, h);
projmean_mean = Wmean' * meanface;
waitbar(0.8, h);
projimage_mean = Wmean' * faces;
waitbar(1, h);
close(h);

% Form Wsvd1, Wsvd2, projected meanface and images for using SVD1 and SVD2
h=waitbar(0,'Finding Wsvd1, Wsvd2, projected meanfaces and images for SVD...');
count = 1;
for i = 1:dirnum
    temp = faces(:,count:count+num(i)-1);
    count = count + num(i);
    [U0,S0,V0] = svd(temp, 0);
    svd1(:,i) = U0(:,1);
    svd2(:,2*i-1:2*i) = U0(:,1:2);
    waitbar(0.7*i/dirnum, h);
end
[Wsvd1, R] = qr(svd1, 0);
waitbar(0.75, h);
[Wsvd2, R] = qr(svd2, 0);
waitbar(0.8, h);
projmean_svd1 = Wsvd1' * meanface;
waitbar(0.85, h);
projimage_svd1 = Wsvd1' * faces;
waitbar(0.9, h);
projmean_svd2 = Wsvd2' * meanface;
waitbar(0.95, h);
projimage_svd2 = Wsvd2' * faces;
waitbar(1, h);
close(h);


% Find errors for FF
h = waitbar(0.1, 'Calculating the Reconstruction Errors for Fisherface ...');
rimage = Wopt * (Wopt' * faces);
for i = 1:dirnum-1
    f = Wopt(:,1:i) * (transpose(Wopt(:,1:i)) * faces);
    errors(i) = sum(sum(abs(faces - f), 2));
    waitbar(0.1 + 0.9 * i/(dirnum-1), h);
end
errors = errors / n;
close(h);


% Find errors for QR
h = waitbar(0.1, 'Calculating the Reconstruction Errors for QR ...');
rimage_qr = Wqr * (Wqr' * faces);
for i = 1:dirnum
    f = Wqr(:,1:i) * (transpose(Wqr(:,1:i)) * faces);
    errors_qr(i) = sum(sum(abs(faces - f), 2));
    waitbar(0.1 + 0.9 * i/dirnum, h);
end
errors_qr = errors_qr / n;
close(h);


% Find errors for MEANFACE
h = waitbar(0.1, 'Calculating the Reconstruction Errors for MEANFACE ...');
rimage_mean = Wmean * (Wmean' * faces);
for i = 1:dirnum-1
    f = Wmean(:,1:i) * (transpose(Wmean(:,1:i)) * faces);
    errors_mean(i) = sum(sum(abs(faces - f), 2));
    waitbar(0.1 + 0.9 * i/(dirnum-1), h);
end
errors_mean = errors_mean / n;
close(h);


% Find errors for SVD1
h = waitbar(0.1, 'Calculating the Reconstruction Errors for SVD1 ...');
rimage_svd1 = Wsvd1 * (Wsvd1' * faces);
for i = 1:dirnum
    f = Wsvd1(:,1:i) * (transpose(Wsvd1(:,1:i)) * faces);
    errors_svd1(i) = sum(sum(abs(faces - f), 2));
    waitbar(0.1 + 0.9 * i/dirnum, h);
end
errors_svd1 = errors_svd1 / n;
close(h);

% Find errors for SVD2
h = waitbar(0.1, 'Calculating the Reconstruction Errors for SVD2 ...');
rimage_svd2 = Wsvd2 * (Wsvd2' * faces);
for i = 1:dirnum*2
    f = Wsvd2(:,1:i) * (transpose(Wsvd2(:,1:i)) * faces);
    errors_svd2(i) = sum(sum(abs(faces - f), 2));
    waitbar(0.1 + 0.9 * i/(dirnum*2), h);
end
errors_svd2 = errors_svd2 / n;
close(h);


set(findobj('Tag', 'load_image_pb'), 'Enable', 'off');
set(findobj('Tag', 'load_project_pb'), 'Enable', 'off');
set(findobj('Tag', 'show_mb'), 'Enable', 'on');
set(findobj('Tag', 'save_project_pb'), 'Enable', 'on');
set(findobj('Tag', 'classify_pb'), 'Enable', 'on');
set(findobj('Tag', 'show_mb'), 'Value', 1);
set(findobj('Tag', 'show_list'), 'Value', 1);

imagestr = cell(n, 1);
for i = 1:n
    imagestr(i) = cellstr(['Image ', int2str(i)]);
end

meanstr = cell(dirnum, 1);
for i = 1:dirnum
    meanstr(i) = cellstr(['Mean ', int2str(i)]);
end

fishstr = cell(dirnum-1, 1);
for i = 1:dirnum-1
    fishstr(i) = cellstr(['FisherFace ', int2str(i)]);
end

qrstr = cell(dirnum, 1);
for i = 1:dirnum
    qrstr(i) = cellstr(['QR Face ', int2str(i)]);
end

meanfacestr = cell(dirnum, 1);
for i = 1:dirnum-1
    meanfacestr(i) = cellstr(['MeanFace ', int2str(i)]);
end

svd1str = cell(dirnum, 1);
for i = 1:dirnum
    svd1str(i) = cellstr(['SVD1 Face ', int2str(i)]);
end

svd2str = cell(2*dirnum, 1);
for i = 1:dirnum*2
    svd2str(i) = cellstr(['SVD2 Face ', int2str(i)]);
end
